@@ -1,5 +1,7 @@
 #!/usr/bin/python
+from __future__ import print_function
 
+import io
 import os.path
 import shutil
 import sys
@@ -11,19 +13,19 @@ import xdg.DesktopEntry
 import resources
 
 def show_menu(menu, depth = 0):
-#    print depth*"-" + "\x1b[01m" + menu.getName().encode("ascii", 'ignore') + "\x1b[0m"
-#    depth += 1
+    print(depth*"-" + "\x1b[01m" + menu.getName() + "\x1b[0m")
+    depth += 1
     for entry in menu.getEntries():
         if isinstance(entry, xdg.Menu.Menu):
             show_menu(entry, depth)
         elif isinstance(entry, xdg.Menu.MenuEntry):
-#            print depth*"-" + entry.DesktopEntry.getName().encode("ascii", 'ignore')
-            print(menu.getPath() + "/\t" + entry.DesktopFileID + "\t" + entry.DesktopEntry.getFileName())
-#        elif isinstance(entry, xdg.Menu.Separator):
-#            print depth*"-" + "|||"
-#        elif isinstance(entry, xdg.Menu.Header):
-#            print depth*"-" + "\x1b[01m" + entry.Name + "\x1b[0m"
-#    depth -= 1
+            print(depth*"-" + entry.DesktopEntry.getName())
+            print(depth*" " + menu.getPath(), entry.DesktopFileID, entry.DesktopEntry.getFileName())
+        elif isinstance(entry, xdg.Menu.Separator):
+            print(depth*"-" + "|||")
+        elif isinstance(entry, xdg.Menu.Header):
+            print(depth*"-" + "\x1b[01m" + entry.Name + "\x1b[0m")
+    depth -= 1
 
 class MenuTest(unittest.TestCase):
     def setUp(self):
@@ -44,3 +46,12 @@ class MenuTest(unittest.TestCase):
         menu.getGenericName()
         menu.getComment()
         menu.getIcon()
+    
+    def test_unicode_menuentry(self):
+        test_file = os.path.join(self.tmpdir, "unicode.desktop")
+        with io.open(test_file, 'w', encoding='utf-8') as f:
+            f.write(resources.unicode_desktop)
+        
+        entry = xdg.Menu.MenuEntry(test_file)
+        assert entry == entry
+        assert not entry < entry
